@@ -109,6 +109,8 @@ def uniform_validator(validator, variables_mapping: VariablesMapping = None,
             if eval(condition) is True:
                 expect_value = compare_values[2]
             else:
+                if compare_values[3] is None:
+                    return
                 expect_value = compare_values[3]
         if len(compare_values) != 3 and len(compare_values) != 5:
             message = ""
@@ -169,7 +171,12 @@ class ResponseObject(object):
             "body": self.body,
         }
         try:
-            check_value = jmespath.search(expr, resp_obj_meta)
+            key_list = [key for key in resp_obj_meta.keys()]
+            flag = False
+            for k in key_list:
+                if k in expr:
+                    flag = True
+            check_value = jmespath.search(expr, resp_obj_meta) if flag is True else expr
         except JMESPathError as ex:
             check_value = parse_string_value(expr)
             # logger.error(
@@ -223,71 +230,72 @@ class ResponseObject(object):
             u_validator = uniform_validator(v, variables_mapping, functions_mapping)
 
             # check item
-            check_item = u_validator["check"]
-            if isinstance(check_item, str):
-                if "$" in check_item:
-                    # check_item is variable or function
-                    check_item = parse_data(
-                        check_item, variables_mapping, functions_mapping
+            if u_validator is not None:
+                check_item = u_validator["check"]
+                if isinstance(check_item, str):
+                    if "$" in check_item:
+                        # check_item is variable or function
+                        check_item = parse_data(
+                            check_item, variables_mapping, functions_mapping
+                        )
+                        check_item = parse_string_value(check_item)
+
+                if check_item and isinstance(check_item, Text):
+                    check_value = self._search_jmespath(check_item)
+                else:
+                    # variable or function evaluation result is "" or not text
+                    check_value = check_item
+
+                # comparator
+                assert_method = u_validator["assert"]
+                assert_func = get_mapping_function(assert_method, functions_mapping)
+
+                # expect item
+                expect_item = u_validator["expect"]
+                # parse expected value with config/teststep/extracted variables
+                expect_value = parse_data(expect_item, variables_mapping, functions_mapping)
+
+                # message
+                message = u_validator["message"]
+                # parse message with config/teststep/extracted variables
+                message = parse_data(message, variables_mapping, functions_mapping)
+
+                validate_msg = f"assert {check_item} {assert_method} {expect_value}({type(expect_value).__name__})"
+
+                validator_dict = {
+                    "comparator": assert_method,
+                    "check": check_item,
+                    "check_value": check_value,
+                    "expect": expect_item,
+                    "expect_value": expect_value,
+                    "message": message,
+                }
+
+                try:
+                    assert_func(check_value, expect_value, message)
+                    validate_msg += "\t==> pass"
+                    logger.info(validate_msg)
+                    validator_dict["check_result"] = "pass"
+                except AssertionError as ex:
+                    validate_pass = False
+                    validator_dict["check_result"] = "fail"
+                    validate_msg += "\t==> fail"
+                    validate_msg += (
+                        f"\n"
+                        f"check_item: {check_item}\n"
+                        f"check_value: {check_value}({type(check_value).__name__})\n"
+                        f"assert_method: {assert_method}\n"
+                        f"expect_value: {expect_value}({type(expect_value).__name__})"
                     )
-                    check_item = parse_string_value(check_item)
+                    message = str(ex)
+                    if message:
+                        validate_msg += f"\nmessage: {message}"
 
-            if check_item and isinstance(check_item, Text):
-                check_value = self._search_jmespath(check_item)
-            else:
-                # variable or function evaluation result is "" or not text
-                check_value = check_item
+                    logger.error(validate_msg)
+                    failures.append(validate_msg)
 
-            # comparator
-            assert_method = u_validator["assert"]
-            assert_func = get_mapping_function(assert_method, functions_mapping)
+                self.validation_results["validate_extractor"].append(validator_dict)
 
-            # expect item
-            expect_item = u_validator["expect"]
-            # parse expected value with config/teststep/extracted variables
-            expect_value = parse_data(expect_item, variables_mapping, functions_mapping)
-
-            # message
-            message = u_validator["message"]
-            # parse message with config/teststep/extracted variables
-            message = parse_data(message, variables_mapping, functions_mapping)
-
-            validate_msg = f"assert {check_item} {assert_method} {expect_value}({type(expect_value).__name__})"
-
-            validator_dict = {
-                "comparator": assert_method,
-                "check": check_item,
-                "check_value": check_value,
-                "expect": expect_item,
-                "expect_value": expect_value,
-                "message": message,
-            }
-
-            try:
-                assert_func(check_value, expect_value, message)
-                validate_msg += "\t==> pass"
-                logger.info(validate_msg)
-                validator_dict["check_result"] = "pass"
-            except AssertionError as ex:
-                validate_pass = False
-                validator_dict["check_result"] = "fail"
-                validate_msg += "\t==> fail"
-                validate_msg += (
-                    f"\n"
-                    f"check_item: {check_item}\n"
-                    f"check_value: {check_value}({type(check_value).__name__})\n"
-                    f"assert_method: {assert_method}\n"
-                    f"expect_value: {expect_value}({type(expect_value).__name__})"
-                )
-                message = str(ex)
-                if message:
-                    validate_msg += f"\nmessage: {message}"
-
-                logger.error(validate_msg)
-                failures.append(validate_msg)
-
-            self.validation_results["validate_extractor"].append(validator_dict)
-
-        if not validate_pass:
-            failures_string = "\n".join([failure for failure in failures])
-            raise ValidationFailure(failures_string)
+            if not validate_pass:
+                failures_string = "\n".join([failure for failure in failures])
+                raise ValidationFailure(failures_string)
