@@ -136,22 +136,38 @@ class HttpRunner(object):
 
     def __execute(self, aspect: Text, step: TStep, variables_mapping=None,
                   functions_mapping=None, ) -> NoReturn:
-        db = ["mysql", "redis", "mongodb","cmd"]
-        has_db_attr = False
-        for d in db:  # 判断是否有数据源
-            if d in step.variables:
-                has_db_attr = True
+        need_configured_attr = ["mysql", "redis", "mongodb"]
+        not_need_configured_attr = ["cmd"]
+        has_attr = False
+        for attr in need_configured_attr:  # 判断是否有数据源
+            if attr in step.variables:
+                has_attr = True
                 break
 
-        if has_db_attr is True:
-            if aspect == "setup":
+        if aspect == "setup":
+            if not has_attr:
+                for attr in not_need_configured_attr:  # 判断是否有数据源
+                    for setup in step.setup:
+                        if attr in setup:
+                            has_attr = True
+                            break
+
+            if has_attr is True:
                 if step.setup:
                     logger.info("setup begin execute >>>>>>")
                     for s in step.setup:
                         parse_data(
                             s, variables_mapping, functions_mapping
                         )
-            elif aspect == "teardown":
+        elif aspect == "teardown":
+            if not has_attr:
+                for attr in not_need_configured_attr:  # 判断是否有数据源
+                    for teardown in step.teardown:
+                        if attr in teardown:
+                            has_attr = True
+                            break
+
+            if has_attr is True:
                 if step.teardown:
                     logger.info("teardown begin execute >>>>>>")
                     for s in step.teardown:
@@ -182,8 +198,9 @@ class HttpRunner(object):
 
         variables_mapping = step.variables
         # variables_mapping.update(extract_mapping)
-        # 执行setup
-        self.__execute("setup", step, variables_mapping, self.__project_meta.functions)
+        # execute setup
+        if step.setup:
+            self.__execute("setup", step, variables_mapping, self.__project_meta.functions)
 
         # prepare arguments
         method = parsed_request_dict.pop("method")
@@ -225,13 +242,15 @@ class HttpRunner(object):
 
         # extract
         extractors = step.extract
-        extract_mapping = resp_obj.extract(extractors)
+        extract_mapping = resp_obj.extract(extractors, variables_mapping, self.__project_meta.functions)
         step_data.export_vars = extract_mapping
 
         variables_mapping = step.variables
         variables_mapping.update(extract_mapping)
         # 执行teardown
-        self.__execute("teardown", step, variables_mapping, self.__project_meta.functions)
+        if step.teardown:
+            self.__execute("teardown", step, variables_mapping, self.__project_meta.functions)
+
         # validate
         validators = step.validators
         session_success = False
@@ -376,8 +395,7 @@ class HttpRunner(object):
             step.variables = merge_variables(step.variables, extracted_variables)
             # step variables > testcase config variables
             step.variables = merge_variables(step.variables, self.__config.variables)
-            step.variables = merge_variables(step.variables, self.__config.db)
-            # step.variables = merge_variables(step.variables, step.extra)
+            step.variables = merge_variables(step.variables, self.__config.datasource)
 
             # parse variables
             step.variables = parse_variables_mapping(
@@ -491,12 +509,3 @@ class HttpRunner(object):
         finally:
             logger.remove(log_handler)
             logger.info(f"generate testcase log: {self.__log_path}")
-
-
-if __name__ == '__main__':
-    list_a = ["a", "b"]
-    dict_b = {"a": "1", "b": "2", "c": "3", "d": "4"}
-    for l in list_a:
-        if l in dict_b:
-            print(l in dict_b)
-            break
